pub struct SliderCustomStyle(/* private fields */);Implementations
Sourceimpl SliderCustomStyle
impl SliderCustomStyle
pub fn new() -> SliderCustomStyle
Sourcepub fn handle_color(self, color: impl Into<Brush>) -> SliderCustomStyle
pub fn handle_color(self, color: impl Into<Brush>) -> SliderCustomStyle
Sets the color of the slider handle.
Arguments
color- An optionalBrushthat sets the handle’s color.
Sourcepub fn edge_align(self, align: bool) -> SliderCustomStyle
pub fn edge_align(self, align: bool) -> SliderCustomStyle
Sets the edge alignment of the slider handle.
Arguments
align- A boolean value that determines the alignment of the handle. Iftrue, the edges of the handle are within the bar at 0% and 100%. Iffalse, the bars are shortened and the handle’s center appears at the ends of the bar.
Sourcepub fn handle_radius(self, radius: impl Into<Length>) -> SliderCustomStyle
pub fn handle_radius(self, radius: impl Into<Length>) -> SliderCustomStyle
Sets the radius of the slider handle.
Arguments
radius- APxPctvalue that sets the handle’s radius. This can be a pixel value or a percent value relative to the main height of the view.
Sourcepub fn bar_color(self, color: impl Into<Brush>) -> SliderCustomStyle
pub fn bar_color(self, color: impl Into<Brush>) -> SliderCustomStyle
Sets the color of the slider’s bar.
Arguments
color- An optionalBrushthat sets the bar’s background color.
Sourcepub fn bar_radius(self, radius: impl Into<Length>) -> SliderCustomStyle
pub fn bar_radius(self, radius: impl Into<Length>) -> SliderCustomStyle
Sets the border radius of the slider’s bar.
Arguments
radius- APxPctvalue that sets the bar’s border radius. This can be a pixel value or a percent value relative to the bar’s height.
Sourcepub fn bar_height(self, height: impl Into<LengthAuto>) -> SliderCustomStyle
pub fn bar_height(self, height: impl Into<LengthAuto>) -> SliderCustomStyle
Sets the height of the slider’s bar.
Arguments
height- APxPctAutovalue that sets the bar’s height. This can be a pixel value, a percent value relative to the view’s height, orAutoto use the view’s height.
Sourcepub fn accent_bar_color(self, color: impl Into<Brush>) -> SliderCustomStyle
pub fn accent_bar_color(self, color: impl Into<Brush>) -> SliderCustomStyle
Sets the color of the slider’s accent bar.
Arguments
color- ABrushthat sets the accent bar’s background color.
Sourcepub fn accent_bar_radius(self, radius: impl Into<Length>) -> SliderCustomStyle
pub fn accent_bar_radius(self, radius: impl Into<Length>) -> SliderCustomStyle
Sets the border radius of the slider’s accent bar.
Arguments
radius- APxPctvalue that sets the accent bar’s border radius. This can be a pixel value or a percent value relative to the accent bar’s height.
Sourcepub fn accent_bar_height(
self,
height: impl Into<LengthAuto>,
) -> SliderCustomStyle
pub fn accent_bar_height( self, height: impl Into<LengthAuto>, ) -> SliderCustomStyle
Sets the height of the slider’s accent bar.
Arguments
height- APxPctAutovalue that sets the accent bar’s height. This can be a pixel value, a percent value relative to the view’s height, orAutoto use the view’s height.