pub struct SliderState {
pub px: f64,
pub pct: Pct,
pub value: f64,
}Expand description
State of a slider at a point in time
Fields
px: f64The value in pixels from the start of the slider
pct: PctThe value as a percentage (0.0 to 100.0)
value: f64The value mapped to the slider’s configured range
Implementations
Sourceimpl SliderState
impl SliderState
Sourcepub fn from_percent(
percent: f64,
range: &RangeInclusive<f64>,
step: Option<f64>,
px: f64,
) -> SliderState
pub fn from_percent( percent: f64, range: &RangeInclusive<f64>, step: Option<f64>, px: f64, ) -> SliderState
Create a new slider state from a percentage